Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7453)

Unified Diff: chrome/browser/ui/cocoa/exclusive_access_bubble_window_controller.h

Issue 789403002: Rename fullscreen_exit_bubble_* to exclusive_access_bubble_* (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Updated based on CR comments Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/exclusive_access_bubble_window_controller.h
diff --git a/chrome/browser/ui/cocoa/fullscreen_exit_bubble_controller.h b/chrome/browser/ui/cocoa/exclusive_access_bubble_window_controller.h
similarity index 67%
rename from chrome/browser/ui/cocoa/fullscreen_exit_bubble_controller.h
rename to chrome/browser/ui/cocoa/exclusive_access_bubble_window_controller.h
index f2ce3546a866670625e3f8523e17b80a0b11d365..fda0854ad9e877783c8be089bd3592ee20bb9b93 100644
--- a/chrome/browser/ui/cocoa/fullscreen_exit_bubble_controller.h
+++ b/chrome/browser/ui/cocoa/exclusive_access_bubble_window_controller.h
@@ -5,23 +5,24 @@
#import <Cocoa/Cocoa.h>
#include "base/mac/scoped_nsobject.h"
-#include "chrome/browser/ui/fullscreen/fullscreen_exit_bubble_type.h"
+#include "chrome/browser/ui/fullscreen/exclusive_access_bubble_type.h"
#include "url/gurl.h"
@class BrowserWindowController;
class Browser;
@class GTMUILocalizerAndLayoutTweaker;
-// The FullscreenExitBubbleController manages the bubble that tells the user
-// how to escape fullscreen mode. The bubble only appears when a tab requests
-// fullscreen mode via webkitRequestFullScreen().
-@interface FullscreenExitBubbleController :
- NSWindowController<NSTextViewDelegate, NSAnimationDelegate> {
+// The ExclusiveAccessBubbleWindowController manages the bubble that informs the
+// user of different exclusive access state like fullscreen mode, mouse lock,
+// etc. Refer to EXCLUSIVE_ACCESS_BUBBLE_TYPE for the different possible
+// conntents of the bubble.
+@interface ExclusiveAccessBubbleWindowController
+ : NSWindowController<NSTextViewDelegate, NSAnimationDelegate> {
@private
BrowserWindowController* owner_; // weak
- Browser* browser_; // weak
+ Browser* browser_; // weak
GURL url_;
- FullscreenExitBubbleType bubbleType_;
+ ExclusiveAccessBubbleType bubbleType_;
@protected
IBOutlet NSTextField* exitLabelPlaceholder_;
@@ -44,7 +45,7 @@ class Browser;
- (id)initWithOwner:(BrowserWindowController*)owner
browser:(Browser*)browser
url:(const GURL&)url
- bubbleType:(FullscreenExitBubbleType)bubbleType;
+ bubbleType:(ExclusiveAccessBubbleType)bubbleType;
- (void)allow:(id)sender;
- (void)deny:(id)sender;
@@ -52,7 +53,7 @@ class Browser;
- (void)showWindow;
- (void)closeImmediately;
-// Positions the fullscreen exit bubble in the top-center of the window.
+// Positions the exclusive access bubble in the top-center of the window.
- (void)positionInWindowAtTop:(CGFloat)maxY width:(CGFloat)maxWidth;
@end

Powered by Google App Engine
This is Rietveld 408576698